@@ -20,8 +20,7 @@ def arg_parse(config_file):
     parser.add_argument('--check', action='store_true', help='ensure all prerequisites are met')
     parser.add_argument('--config', action='store_true', help='create/view a config file (/.config/robin/software_deployment.yaml)')
     parser.add_argument('--upload', action='store_true', help='upload software to the server: python3 robin_sd_upload --upload --type=radar_type --version=version_name')
-
-    parser = argparse.ArgumentParser(description='argument parses for upload script.')
+    # parser = argparse.ArgumentParser(description='argument parses for upload script.')
     parser.add_argument("--type", type=str, help="radar type")
     parser.add_argument("--version", type=str, help="version name")
     parser.add_argument("--filepath", type=str, help="file path")
